pub enum DocumentBuilderError {
SchemaMustBeSet,
InvalidOperationLink(OperationId),
MultipleCreateOperations,
DocumentViewError(DocumentViewError),
GraphSortingError(GraphError),
DocumentReducerError(DocumentReducerError),
}Expand description
Error types for methods of DocumentBuilder struct.
Variants
SchemaMustBeSet
To resolve a document the schema must be set.
InvalidOperationLink(OperationId)
An operation with invalid id or previous operations was added to the document.
MultipleCreateOperations
A document can only contain one CREATE operation.
DocumentViewError(DocumentViewError)
Handle errors from validating CBOR schemas.
GraphSortingError(GraphError)
Handle errors when sorting the graph.
DocumentReducerError(DocumentReducerError)
Handle errors from DocumentReducer.