pub enum DocumentError {
PreviousDoesNotMatch(OperationId),
InvalidSchemaId(OperationId),
UpdateOnDeleted,
CommitCreate,
DocumentViewError(DocumentViewError),
GraphSortingError(GraphError),
}Expand description
Error types for methods of Document struct.
Variants
PreviousDoesNotMatch(OperationId)
Operation passed to commit does not refer to this documents current view.
InvalidSchemaId(OperationId)
Operation passed to commit does not the same schema as the document.
UpdateOnDeleted
Cannot perform a commit on a deleted document.
CommitCreate
Cannot perform a commit with a create operation.
DocumentViewError(DocumentViewError)
Handle errors coming from DocumentView.
GraphSortingError(GraphError)
Handle errors when sorting the graph.