pub struct DocumentBuilder(/* private fields */);Expand description
A struct for building documents from a collection of operations.
Implementations
Sourceimpl DocumentBuilder
impl DocumentBuilder
Sourcepub fn new(operations: Vec<(OperationId, Operation, PublicKey)>) -> Self
pub fn new(operations: Vec<(OperationId, Operation, PublicKey)>) -> Self
Instantiate a new DocumentBuilder from a collection of operations.
Sourcepub fn operations(&self) -> &Vec<(OperationId, Operation, PublicKey)>
pub fn operations(&self) -> &Vec<(OperationId, Operation, PublicKey)>
Get all unsorted operations for this document.
Sourcepub fn build(
&self,
) -> Result<(Document, Vec<(OperationId, Operation, PublicKey)>), DocumentBuilderError>
pub fn build( &self, ) -> Result<(Document, Vec<(OperationId, Operation, PublicKey)>), DocumentBuilderError>
Validates all contained operations and builds the document.
The returned document contains the latest resolved [document view][DocumentView].
Validation checks the following:
- There is exactly one
CREATEoperation. - All operations are causally connected to the root operation.
- All operations follow the same schema.
- No cycles exist in the graph.
Sourcepub fn build_to_view_id(
&self,
document_view_id: DocumentViewId,
) -> Result<(Document, Vec<(OperationId, Operation, PublicKey)>), DocumentBuilderError>
pub fn build_to_view_id( &self, document_view_id: DocumentViewId, ) -> Result<(Document, Vec<(OperationId, Operation, PublicKey)>), DocumentBuilderError>
Validates all contained operations and builds the document up to the
requested DocumentViewId.
The returned document contains the requested [document view][DocumentView].
Validation checks the following:
- There is exactly one
CREATEoperation. - All operations are causally connected to the root operation.
- All operations follow the same schema.
- No cycles exist in the graph.