DocumentView

Struct DocumentView 

pub struct DocumentView { /* private fields */ }
The materialised view of a Document. It’s fields match the documents schema definition.

DocumentViews are immutable versions of a Document. They represent a document at a certain point in time.

Implementations

Source

impl DocumentView

pub fn new(id: &DocumentViewId, fields: &DocumentViewFields) -> Self

Construct a document view.

Requires the DocumentViewId and field values to be calculated seperately and then passed in during construction.

pub fn id(&self) -> &DocumentViewId

Get the id of this document view.

pub fn get(&self, key: &str) -> Option<&DocumentViewValue>

Get a single value from this instance by it’s key.

pub fn keys(&self) -> Vec<String>

Returns a vector containing the keys of this instance.

pub fn iter(&self) -> BTreeMapIter<'_, String, DocumentViewValue>

Returns an iterator of existing instance fields.

pub fn len(&self) -> usize

Returns the number of fields on this instance.

pub fn is_empty(&self) -> bool

Returns true if the instance is empty, otherwise false.

pub fn fields(&self) -> &DocumentViewFields

Returns the fields of this document view.