pub struct DocumentViewFields(/* private fields */);Expand description
A key value map of field keys to DocumentViewValues.
Implementations
Sourceimpl DocumentViewFields
impl DocumentViewFields
Sourcepub fn new_from_operation_fields(
id: &OperationId,
fields: &OperationFields,
) -> Self
pub fn new_from_operation_fields( id: &OperationId, fields: &OperationFields, ) -> Self
Creates a new populated fields instance from existing OperationFields and OperationId.
Sourcepub fn insert(
&mut self,
name: &str,
value: DocumentViewValue,
) -> Option<DocumentViewValue>
pub fn insert( &mut self, name: &str, value: DocumentViewValue, ) -> Option<DocumentViewValue>
Insert a new field to this instance.
Sourcepub fn get(&self, name: &str) -> Option<&DocumentViewValue>
pub fn get(&self, name: &str) -> Option<&DocumentViewValue>
Returns a field value.
Sourcepub fn iter(&self) -> Iter<'_, String, DocumentViewValue>
pub fn iter(&self) -> Iter<'_, String, DocumentViewValue>
Returns an iterator of existing document view fields.