pub struct DocumentViewValue { /* private fields */ }Expand description
The current value of a document fiew field as well as the id of the operation it came from.
Implementations
Sourceimpl DocumentViewValue
impl DocumentViewValue
Sourcepub fn new(operation_id: &OperationId, value: &OperationValue) -> Self
pub fn new(operation_id: &OperationId, value: &OperationValue) -> Self
Returns a DocumentViewValue constructed from an OperationId and OperationValue.
Sourcepub fn id(&self) -> &OperationId
pub fn id(&self) -> &OperationId
Get the OperationId of this document value.
Sourcepub fn value(&self) -> &OperationValue
pub fn value(&self) -> &OperationValue
Get the OperationValue of this document value.