pub fn encode_entry(entry: &Entry) -> Result<EncodedEntry, EncodeEntryError>Expand description
Encodes an entry into bytes and returns them as EncodedEntry instance. After encoding this is
ready to be sent to a p2panda node.
This method only fails if something went wrong with the encoder or if a backlink was provided on an entry with sequence number 1 (#E3).