EncodedEntry

Struct EncodedEntry 

pub struct EncodedEntry(/* private fields */);
Wrapper type for Bamboo entry bytes.

This struct can be used to deserialize an hex-encoded string into bytes when using a human-readable encoding format. No validation is applied whatsoever, except of checking if it is a valid hex-string (#E1).

To validate these bytes use the decode_entry method to apply all checks and to get an Entry instance. Read the module-level documentation for more information.

Implementations

Source

impl EncodedEntry

pub fn from_bytes(bytes: &[u8]) -> Self

Returns new EncodedEntry instance from given bytes.

This does not apply any validation and should only be used in methods where all checks have taken place before.