Entry

Struct Entry 

pub struct Entry { /* private fields */ }
Entry of an append-only log based on Bamboo specification.

Bamboo entries are the main data type of p2panda. They describe the actual data in the p2p network and are shared between nodes. Entries are organised in a distributed, single-writer append-only log structure, created and signed by holders of private keys and stored inside the node’s database.

Entries are separated from the actual (off-chain) data to be able to delete application data without loosing the integrity of the log. Payload data is formatted as “operations” in p2panda. Each entry only holds a hash of the operation payload, this is why an [Operation] instance is required during entry signing.

It is not possible to directly create an Entry instance without validation, use the EntryBuilder to programmatically create and sign one or decode it from bytes via the EncodedEntry struct.