EntryBuilder

Struct EntryBuilder 

pub struct EntryBuilder { /* private fields */ }
Create and sign new Entry instances.

Implementations

Source

impl EntryBuilder

pub fn new() -> Self

Returns a new instance of EntryBuilder.

pub fn log_id(self, log_id: &LogId) -> Self

Set log id of entry.

pub fn seq_num(self, seq_num: &SeqNum) -> Self

Set sequence number of entry.

Set skiplink hash of entry.

Set backlink hash of entry.

pub fn sign( &self, encoded_operation: &EncodedOperation, key_pair: &KeyPair, ) -> Result<Entry, EntryBuilderError>

Signs entry and secures payload with the author’s key pair, returns a new Entry instance.

An EncodedOperation is required here for the entry payload. The entry is “pointing” at the payload to secure and authenticate it. Later on, the payload can theoretically be deleted when it is not needed anymore.

Using this method we can assume that the entry will be correctly signed. This applies only basic checks if the backlink and skiplink is correctly set for the given sequence number (#E3). Please note though that this method can not check for correct log integrity!