Hash

Struct Hash 

pub struct Hash(/* private fields */);
Hash of Entry or Operation encoded as hex string.

This uses the BLAKE3 algorithm wrapped in YASMF “Yet-Another-Smol-Multi-Format” according to the Bamboo specification.

Implementations

Source

impl Hash

pub fn new(value: &str) -> Result<Self, HashError>

Validates and wraps encoded hash string into new Hash instance.

pub fn new_from_bytes(value: &[u8]) -> Self

Hashes byte data and returns it as Hash instance.

pub fn to_bytes(&self) -> Vec<u8>

Returns hash as bytes.

pub fn as_str(&self) -> &str

Returns hash as &str.