pub enum OperationVersion {
V1,
}Expand description
Operation format versions to introduce API changes in the future.
Operations contain the actual data of applications in the p2panda network and will be stored for an indefinite time on different machines. To allow an upgrade path in the future and support backwards compatibility for old data we can use this version number.
Variants
V1
The latest version number.
Implementations