pub struct EncodedOperation(/* private fields */);Expand description
Wrapper type for operation bytes.
This struct can be used to deserialize an hex-encoded string into bytes when using a human-readable encoding format. No validation is applied whatsoever, except of checking if it is a valid hex-string (#OP1).
To validate these bytes use the decode_operation method to get an PlainOperation instance.
From there you can derive a Schema to finally validate the operation with
validate_operation. Read the module-level documentation for more information.
Implementations
Sourceimpl EncodedOperation
impl EncodedOperation
Sourcepub fn from_bytes(bytes: &[u8]) -> Self
pub fn from_bytes(bytes: &[u8]) -> Self
Returns new EncodedOperation instance from given bytes.
This does not apply any validation and should only be used in methods where all checks have taken place before.
Sourcepub fn into_bytes(&self) -> Vec<u8> ⓘ
pub fn into_bytes(&self) -> Vec<u8> ⓘ
Returns operation as bytes.