PinnedRelationList

Struct PinnedRelationList 

pub struct PinnedRelationList(/* private fields */);
A PinnedRelationList can be used to reference multiple documents views.

The item order and occurrences inside a pinned relation list are defined by the developers and users and have semantic meaning, for this reason we do not check against duplicates or ordering here.

Implementations

Source

impl PinnedRelationList

pub fn new(relations: Vec<DocumentViewId>) -> Self

Returns a new list of pinned relations.

pub fn document_view_ids(&self) -> &[DocumentViewId]

Returns the list of document view ids.

pub fn iter(&self) -> Iter<'_, DocumentViewId>

Returns iterator over document view ids.

pub fn len(&self) -> usize

Returns number of pinned documents in this list.