pub struct SchemaDescription(/* private fields */);Expand description
The description of a schema which adheres to specification requirements. Used in the
construction of Schema.
Implementations
Sourceimpl SchemaDescription
impl SchemaDescription
Sourcepub fn new(description: &str) -> Result<Self, SchemaDescriptionError>
pub fn new(description: &str) -> Result<Self, SchemaDescriptionError>
Construct and validate new schema description from a string.