pub enum SecretGroupError {
NotOwner,
WelcomeMissing,
LTSInvalidGroupID,
LTSSecretMissing,
LTSEncodingError,
LTSDecodingError,
InvalidMemberPublicKey,
UnknownValue,
MlsError(MlsError),
LTSError(LongTermSecretError),
}Expand description
Custom error types for SecretGroup.
Variants
NotOwner
Commit messages and new long-term secrets can only be created by group owners.
WelcomeMissing
MLS commit message was expected to contain a welcome message as well.
LTSInvalidGroupID
Long-term secret does not match current secret group.
LTSSecretMissing
User data could not be decrypted since long-term secret is missing.
LTSEncodingError
LTS secret encoding failed.
LTSDecodingError
LTS secret decoding failed. Maybe the data was corrupted or invalid?
InvalidMemberPublicKey
Member’s public key cannot be decoded as an Ed25519 public key.
UnknownValue
Decoding failed with unknown value.
MlsError(MlsError)
Error coming from mls sub-module.
LTSError(LongTermSecretError)
Error coming from lts sub-module.