pub enum DocumentStorageError {
Custom(String),
FatalStorageError(String),
DocumentViewInsertionError(DocumentViewId),
DocumentInsertionError(DocumentId),
OperationValidation(ValidateOperationError),
OperationStorageError(OperationStorageError),
DocumentBuilderError(DocumentBuilderError),
}Expand description
DocumentStore errors.
Variants
Custom(String)
Catch all error which implementers can use for passing their own errors up the chain.
FatalStorageError(String)
A fatal error occured when performing a storage query.
DocumentViewInsertionError(DocumentViewId)
Error which originates in insert_document_view() when the insertion fails.
DocumentInsertionError(DocumentId)
Error which originates in insert_document() when the insertion fails.
OperationValidation(ValidateOperationError)
Error returned from validating p2panda-rs Operation data types.
OperationStorageError(OperationStorageError)
Error returned from OperationStorage.
DocumentBuilderError(DocumentBuilderError)
Error returned from DocumentBuilder.