Document

Struct Document 

pub struct Document { /* private fields */ }
High-level datatype representing data published to the p2panda network as key-value pairs.

Documents are multi-writer and have automatic conflict resolution strategies which produce deterministic state for any two replicas. The underlying structure which make this possible is a directed acyclic graph of Operation’s. To arrive at the current state of a document the graph is topologically sorted, with any branches being ordered according to the conflicting operations OperationId. Each operation’s mutation is applied in order which results in a LWW (last write wins) resolution strategy.

All documents have an accompanying Schema which describes the shape of the data they will contain. Every operation should have been validated against this schema before being included in the graph.

Documents are constructed through the DocumentBuilder or by conversion from vectors of a type implementing the AsOperation, WithId<OperationId> and WithPublicKey.

To efficiently commit more operations to an already constructed document use the commit method. Any operations committed in this way must refer to the documents current view id in their previous field.

See module docs for example uses.