pub struct DocumentView { /* private fields */ }Expand description
The materialised view of a Document. It’s fields match the documents schema definition.
DocumentViews are immutable versions of a Document. They represent a document at a certain
point in time.
Implementations
Sourceimpl DocumentView
impl DocumentView
Sourcepub fn new(id: &DocumentViewId, fields: &DocumentViewFields) -> Self
pub fn new(id: &DocumentViewId, fields: &DocumentViewFields) -> Self
Construct a document view.
Requires the DocumentViewId and field values to be calculated seperately and then passed in during construction.
Sourcepub fn id(&self) -> &DocumentViewId
pub fn id(&self) -> &DocumentViewId
Get the id of this document view.
Sourcepub fn get(&self, key: &str) -> Option<&DocumentViewValue>
pub fn get(&self, key: &str) -> Option<&DocumentViewValue>
Get a single value from this instance by it’s key.
Sourcepub fn iter(&self) -> BTreeMapIter<'_, String, DocumentViewValue>
pub fn iter(&self) -> BTreeMapIter<'_, String, DocumentViewValue>
Returns an iterator of existing instance fields.
Sourcepub fn fields(&self) -> &DocumentViewFields
pub fn fields(&self) -> &DocumentViewFields
Returns the fields of this document view.