pub struct DocumentViewId(/* private fields */);Expand description
The identifier of a document view.
Contains the operation ids of the document graph tips, which is all the information we need to reliably reconstruct a specific version of a document.
Document view ids are considered equal if they contain the same set of operation ids, independent of their order. Serialised document view ids always contain sorted operation ids and deserialisation of a value will fail if this does not hold. This follows p2panda’s requirement that all serialised arrays must be sorted and leads to deterministic serialisation.
The document with the following operation graph has the id "2fa.." and six different document
view ids, meaning that this document can be represented in six versions:
1. ["2fa"]
2. ["de8"]
3. ["89c"]
4. ["eff"]
5. ["de8", "eff"]
6. ["89c", "eff"]
[CREATE] (Hash: "2fa..") <-- [UPDATE] (Hash: "de8..") <-- [UPDATE] (Hash: "89c..")
\
\__ [UPDATE] (Hash: "eff..")Implementations
Sourceimpl DocumentViewId
impl DocumentViewId
Sourcepub fn new(graph_tips: &[OperationId]) -> Self
pub fn new(graph_tips: &[OperationId]) -> Self
Create a new document view id.
The given operation ids will automatically be sorted and de-duplicated.
Sourcepub fn graph_tips(&self) -> &[OperationId]
pub fn graph_tips(&self) -> &[OperationId]
Get the operation ids of this view id.
Sourcepub fn iter(&self) -> Iter<'_, OperationId>
pub fn iter(&self) -> Iter<'_, OperationId>
Get the operation ids of this view id.