pub struct EntryBuilder { /* private fields */ }Expand description
Create and sign new Entry instances.
Implementations
Sourceimpl EntryBuilder
impl EntryBuilder
Sourcepub fn sign(
&self,
encoded_operation: &EncodedOperation,
key_pair: &KeyPair,
) -> Result<Entry, EntryBuilderError>
pub fn sign( &self, encoded_operation: &EncodedOperation, key_pair: &KeyPair, ) -> Result<Entry, EntryBuilderError>
Signs entry and secures payload with the author’s key pair, returns a new Entry instance.
An EncodedOperation is required here for the entry payload. The entry is “pointing” at
the payload to secure and authenticate it. Later on, the payload can theoretically be
deleted when it is not needed anymore.
Using this method we can assume that the entry will be correctly signed. This applies only basic checks if the backlink and skiplink is correctly set for the given sequence number (#E3). Please note though that this method can not check for correct log integrity!