pub struct PinnedRelation(/* private fields */);Expand description
Reference to the exact version of the document.
PinnedRelation pin a relation to a specific, immutable version of a document or many
documents when necessary (PinnedRelation or PinnedRelationList).
When the blog post from the Relation example changes its contents from Monday evening to
Tuesday morning the comment would automatically refer to the new version as the comment
refers to the document as a whole, including all future changes.
Since the comment was probably meant to be referring to Monday when it was created, we have to
pin it to the exact version of the blog post in order to preserve this meaning. A
PinnedRelation achieves this by referring to the blog post’s document view id:
Document-View Document-View
| |
Document: [Blog-Post "Monday evening"] -- UPDATE -- > [Blog-Post "Tuesday morning"]
^
|
_____________| Pinned Relation (we will stay in the "past")
|
|
Document: [Comment "This was great!"]Document view ids contain the operation ids of the document graph tips, which is all the information we need to reliably recreate the document at this certain point in time.
Pinned relations give us immutability and the option to restore a historical state across documents. However, most cases will probably only need unpinned relations: For example when referring to a user-profile you probably want to always get the latest version.
Implementations
Sourceimpl PinnedRelation
impl PinnedRelation
Sourcepub fn new(document_view_id: DocumentViewId) -> Self
pub fn new(document_view_id: DocumentViewId) -> Self
Returns a new pinned relation field.
Sourcepub fn view_id(&self) -> &DocumentViewId
pub fn view_id(&self) -> &DocumentViewId
Returns the pinned relation’s document view id.
Sourcepub fn iter(&self) -> Iter<'_, OperationId>
pub fn iter(&self) -> Iter<'_, OperationId>
Returns iterator over operation ids.