pub struct PinnedRelationList(/* private fields */);Expand description
A PinnedRelationList can be used to reference multiple documents views.
The item order and occurrences inside a pinned relation list are defined by the developers and users and have semantic meaning, for this reason we do not check against duplicates or ordering here.
Implementations
Sourceimpl PinnedRelationList
impl PinnedRelationList
Sourcepub fn new(relations: Vec<DocumentViewId>) -> Self
pub fn new(relations: Vec<DocumentViewId>) -> Self
Returns a new list of pinned relations.
Sourcepub fn document_view_ids(&self) -> &[DocumentViewId]
pub fn document_view_ids(&self) -> &[DocumentViewId]
Returns the list of document view ids.
Sourcepub fn iter(&self) -> Iter<'_, DocumentViewId>
pub fn iter(&self) -> Iter<'_, DocumentViewId>
Returns iterator over document view ids.