ValidationError

Enum ValidationError 

pub enum ValidationError {
    MissingField(String, String),
    UnexpectedFields(String),
    InvalidField(String, String),
    InvalidName(String, String),
    InvalidType(String, String),
    InvalidValue(String),
    InvalidDocumentViewId(String),
    InvalidSchemaDefinition(SchemaDefinitionError),
    InvalidSchemaFieldDefinition(SchemaFieldDefinitionError),
    NotStringValue(PlainValueError),
    InvalidBlob(BlobError),
    InvalidBlobPiece(BlobPieceError),
}
Custom error types for validating raw operations with schemas.

Variants



MissingField(String, String)

Field with this name is required by schema.



UnexpectedFields(String)

One or more fields which do not belong to the schema.



InvalidField(String, String)

Raw operation field did not match schema.



InvalidName(String, String)

Field type and schema do not match.



InvalidType(String, String)

Field type and schema do not match.



InvalidValue(String)

Field value is not correctly formatted.



InvalidDocumentViewId(String)

Field value is not in canonic format.



InvalidSchemaDefinition(SchemaDefinitionError)

Error from validating system schema: schema_definition_v1.



InvalidSchemaFieldDefinition(SchemaFieldDefinitionError)

Error from validating system schema: schema_field_definition_v1.



NotStringValue(PlainValueError)

Error from conversion of PlainValues.



InvalidBlob(BlobError)

Error from validating system schema: blob_v1.



InvalidBlobPiece(BlobPieceError)

Error from validating system schema: blob_piece_v1.